==> koffice_1.3.5.orig.tar.gz: koffice-1.3.5.orig/lib/kofficeui/koPartSelectDia.h <==
/* This file is part of the KDE libraries
    Copyright (C) 1998 Torben Weis <weis@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef DlgPartSelect_included
#define DlgPartSelect_included

#include <kdialogbase.h>
#include <koQueryTrader.h>

class QListView;
class QListViewItem;
class QPushButton;

/**
 *  This dialog presents the user all available
 *  KOffice components ( KSpread, KWord etc ) with name
 *  and mini icon. The user may select one and
 *  the corresponding KoDocumentEntry is returned.
 */
class KoPartSelectDia : public KDialogBase
{
    Q_OBJECT

public:

    /**
     *  Constructor.
     */
    KoPartSelectDia( QWidget* parent = 0, const char* name = 0 );

    /**
     *  Retrieves the result of the part selection.
     *
     *  @return A document entry.
     */
    KoDocumentEntry entry();

    /**
     *  Convenience function for using the dialog.
     *
     *  @returns the KoDocumentEntry of the selected KOffice components
     *           or an empty entry.
     */
    static KoDocumentEntry selectPart( QWidget *parent = 0L );

private slots:
    void selectionChanged( QListViewItem * );

private:
    QValueList<KoDocumentEntry> m_lstEntries;
    QListView *listview;
};

#endif

==> koffice-1.89.tar.gz: koffice-1.89/lib/kofficeui/koPartSelectDia.h <==
/* This file is part of the KDE libraries
    Copyright (C) 1998 Torben Weis <weis@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef DlgPartSelect_included
#define DlgPartSelect_included

#include <kdialogbase.h>
#include <koQueryTypes.h>
#include <qvaluelist.h>

class QListView;
class QListViewItem;
class QPushButton;

/**
 *  This dialog presents the user all available
 *  KOffice components ( KSpread,KWord etc ) with name
 *  and mini icon. The user may select one and
 *  the corresponding KoDocumentEntry is returned.
 */
class KoPartSelectDia : public KDialogBase
{
    Q_OBJECT

public:

    /**
     *  Constructor.
     */
    KoPartSelectDia( QWidget* parent = 0, const char* name = 0 );

    /**
     *  Retrieves the result of the part selection.
     *
     *  @return A document entry.
     */
    KoDocumentEntry entry();

    /**
     *  Convenience function for using the dialog.
     *
     *  @returns the KoDocumentEntry of the selected KOffice components
     *           or an empty entry.
     */
    static KoDocumentEntry selectPart();

private slots:
    void selectionChanged( QListViewItem * );
    
private:
    QValueList<KoDocumentEntry> m_lstEntries;
    QListView *listview;
    QPushButton *okButton;
    
};

#endif
